==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/cy.pl <==
{
  am_pm_abbreviated => [
    "yb",
    "yh"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, E",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-few" => "'wythnos' W 'o' MMM",
    "MMMMW-count-many" => "'wythnos' W 'o' MMM",
    "MMMMW-count-one" => "'wythnos' W 'o' MMM",
    "MMMMW-count-other" => "'wythnos' W 'o' MMM",
    "MMMMW-count-two" => "'wythnos' W 'o' MMM",
    "MMMMW-count-zero" => "'wythnos' W 'o' MMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQ => "Q y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'wythnos' w 'of' y",
    "yw-count-many" => "'wythnos' w 'of' y",
    "yw-count-one" => "'wythnos' w 'of' y",
    "yw-count-other" => "'wythnos' w 'of' y",
    "yw-count-two" => "'wythnos' w 'of' y",
    "yw-count-zero" => "'wythnos' w 'of' y"
  },
  code => "cy",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} 'am' {0}",
  datetime_format_long => "{1} 'am' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Llun",
    "Maw",
    "Mer",
    "Iau",
    "Gwen",
    "Sad",
    "Sul"
  ],
  day_format_narrow => [
    "Ll",
    "M",
    "M",
    "I",
    "G",
    "S",
    "S"
  ],
  day_format_wide => [
    "Dydd Llun",
    "Dydd Mawrth",
    "Dydd Mercher",
    "Dydd Iau",
    "Dydd Gwener",
    "Dydd Sadwrn",
    "Dydd Sul"
  ],
  day_stand_alone_abbreviated => [
    "Llun",
    "Maw",
    "Mer",
    "Iau",
    "Gwe",
    "Sad",
    "Sul"
  ],
  day_stand_alone_narrow => [
    "Ll",
    "M",
    "M",
    "I",
    "G",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "Dydd Llun",
    "Dydd Mawrth",
    "Dydd Mercher",
    "Dydd Iau",
    "Dydd Gwener",
    "Dydd Sadwrn",
    "Dydd Sul"
  ],
  era_abbreviated => [
    "CC",
    "OC"
  ],
  era_narrow => [
    "C",
    "O"
  ],
  era_wide => [
    "Cyn Crist",
    "Oed Crist"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Welsh",
  month_format_abbreviated => [
    "Ion",
    "Chwef",
    "Maw",
    "Ebrill",
    "Mai",
    "Meh",
    "Gorff",
    "Awst",
    "Medi",
    "Hyd",
    "Tach",
    "Rhag"
  ],
  month_format_narrow => [
    "I",
    "Ch",
    "M",
    "E",
    "M",
    "M",
    "G",
    "A",
    "M",
    "H",
    "T",
    "Rh"
  ],
  month_format_wide => [
    "Ionawr",
    "Chwefror",
    "Mawrth",
    "Ebrill",
    "Mai",
    "Mehefin",
    "Gorffennaf",
    "Awst",
    "Medi",
    "Hydref",
    "Tachwedd",
    "Rhagfyr"
  ],
  month_stand_alone_abbreviated => [
    "Ion",
    "Chw",
    "Maw",
    "Ebr",
    "Mai",
    "Meh",
    "Gor",
    "Awst",
    "Medi",
    "Hyd",
    "Tach",
    "Rhag"
  ],
  month_stand_alone_narrow => [
    "I",
    "Ch",
    "M",
    "E",
    "M",
    "M",
    "G",
    "A",
    "M",
    "H",
    "T",
    "Rh"
  ],
  month_stand_alone_wide => [
    "Ionawr",
    "Chwefror",
    "Mawrth",
    "Ebrill",
    "Mai",
    "Mehefin",
    "Gorffennaf",
    "Awst",
    "Medi",
    "Hydref",
    "Tachwedd",
    "Rhagfyr"
  ],
  name => "Welsh",
  native_language => "Cymraeg",
  native_name => "Cymraeg",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Ch1",
    "Ch2",
    "Ch3",
    "Ch4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "chwarter 1af",
    "2il chwarter",
    "3ydd chwarter",
    "4ydd chwarter"
  ],
  quarter_stand_alone_abbreviated => [
    "Ch1",
    "Ch2",
    "Ch3",
    "Ch4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "chwarter 1af",
    "2il chwarter",
    "3ydd chwarter",
    "4ydd chwarter"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/cy.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "d, E",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-few" => "'wythnos' W 'o' MMMM",
    "MMMMW-count-many" => "'wythnos' W 'o' MMMM",
    "MMMMW-count-one" => "'wythnos' W 'o' MMMM",
    "MMMMW-count-other" => "'wythnos' W 'o' MMMM",
    "MMMMW-count-two" => "'wythnos' W 'o' MMMM",
    "MMMMW-count-zero" => "'wythnos' W 'o' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQ => "Q y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-few" => "'wythnos' w 'o' Y",
    "yw-count-many" => "'wythnos' w 'o' Y",
    "yw-count-one" => "'wythnos' w 'o' Y",
    "yw-count-other" => "'wythnos' w 'o' Y",
    "yw-count-two" => "'wythnos' w 'o' Y",
    "yw-count-zero" => "'wythnos' w 'o' Y",
  },
  code => "cy",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} 'am' {0}",
  datetime_format_long => "{1} 'am' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Llun",
    "Maw",
    "Mer",
    "Iau",
    "Gwen",
    "Sad",
    "Sul",
  ],
  day_format_narrow => [
    "Ll",
    "M",
    "M",
    "I",
    "G",
    "S",
    "S",
  ],
  day_format_wide => [
    "Dydd Llun",
    "Dydd Mawrth",
    "Dydd Mercher",
    "Dydd Iau",
    "Dydd Gwener",
    "Dydd Sadwrn",
    "Dydd Sul",
  ],
  day_stand_alone_abbreviated => [
    "Llun",
    "Maw",
    "Mer",
    "Iau",
    "Gwe",
    "Sad",
    "Sul",
  ],
  day_stand_alone_narrow => [
    "Ll",
    "M",
    "M",
    "I",
    "G",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Dydd Llun",
    "Dydd Mawrth",
    "Dydd Mercher",
    "Dydd Iau",
    "Dydd Gwener",
    "Dydd Sadwrn",
    "Dydd Sul",
  ],
  era_abbreviated => [
    "CC",
    "OC",
  ],
  era_narrow => [
    "C",
    "O",
  ],
  era_wide => [
    "Cyn Crist",
    "Oed Crist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Welsh",
  month_format_abbreviated => [
    "Ion",
    "Chwef",
    "Maw",
    "Ebr",
    "Mai",
    "Meh",
    "Gorff",
    "Awst",
    "Medi",
    "Hyd",
    "Tach",
    "Rhag",
  ],
  month_format_narrow => [
    "I",
    "Ch",
    "M",
    "E",
    "M",
    "M",
    "G",
    "A",
    "M",
    "H",
    "T",
    "Rh",
  ],
  month_format_wide => [
    "Ionawr",
    "Chwefror",
    "Mawrth",
    "Ebrill",
    "Mai",
    "Mehefin",
    "Gorffennaf",
    "Awst",
    "Medi",
    "Hydref",
    "Tachwedd",
    "Rhagfyr",
  ],
  month_stand_alone_abbreviated => [
    "Ion",
    "Chw",
    "Maw",
    "Ebr",
    "Mai",
    "Meh",
    "Gor",
    "Awst",
    "Medi",
    "Hyd",
    "Tach",
    "Rhag",
  ],
  month_stand_alone_narrow => [
    "I",
    "Ch",
    "M",
    "E",
    "M",
    "M",
    "G",
    "A",
    "M",
    "H",
    "T",
    "Rh",
  ],
  month_stand_alone_wide => [
    "Ionawr",
    "Chwefror",
    "Mawrth",
    "Ebrill",
    "Mai",
    "Mehefin",
    "Gorffennaf",
    "Awst",
    "Medi",
    "Hydref",
    "Tachwedd",
    "Rhagfyr",
  ],
  name => "Welsh",
  native_language => "Cymraeg",
  native_name => "Cymraeg",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Ch1",
    "Ch2",
    "Ch3",
    "Ch4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "chwarter 1af",
    "2il chwarter",
    "3ydd chwarter",
    "4ydd chwarter",
  ],
  quarter_stand_alone_abbreviated => [
    "Ch1",
    "Ch2",
    "Ch3",
    "Ch4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "chwarter 1af",
    "2il chwarter",
    "3ydd chwarter",
    "4ydd chwarter",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
